@@ -12,6 +12,9 @@ from airbyte_cdk.sources.declarative.models import (
 from airbyte_cdk.sources.declarative.models import (
     HttpComponentsResolver as HttpComponentsResolverModel,
 )
+from airbyte_cdk.sources.declarative.models import (
+    ParametrizedComponentsResolver as ParametrizedComponentsResolverModel,
+)
 from airbyte_cdk.sources.declarative.resolvers.components_resolver import (
     ComponentMappingDefinition,
     ComponentsResolver,
@@ -24,10 +27,15 @@ from airbyte_cdk.sources.declarative.resolvers.config_components_resolver import
 from airbyte_cdk.sources.declarative.resolvers.http_components_resolver import (
     HttpComponentsResolver,
 )
+from airbyte_cdk.sources.declarative.resolvers.parametrized_components_resolver import (
+    ParametrizedComponentsResolver,
+    StreamParametersDefinition,
+)
 
 COMPONENTS_RESOLVER_TYPE_MAPPING: Mapping[str, type[BaseModel]] = {
     "HttpComponentsResolver": HttpComponentsResolverModel,
     "ConfigComponentsResolver": ConfigComponentsResolverModel,
+    "ParametrizedComponentsResolver": ParametrizedComponentsResolverModel,
 }
 
 __all__ = [
@@ -38,4 +46,6 @@ __all__ = [
     "StreamConfig",
     "ConfigComponentsResolver",
     "COMPONENTS_RESOLVER_TYPE_MAPPING",
+    "ParametrizedComponentsResolver",
+    "StreamParametersDefinition",
 ]
