@@ -64,12 +64,6 @@ class AbstractStream(ABC):
         :return: The name of the field used as a cursor. Nested cursor fields are not supported.
         """
 
-    @abstractmethod
-    def check_availability(self) -> StreamAvailability:
-        """
-        :return: The stream's availability
-        """
-
     @abstractmethod
     def get_json_schema(self) -> Mapping[str, Any]:
         """
@@ -94,3 +88,9 @@ class AbstractStream(ABC):
         """
         :return: The cursor associated with this stream.
         """
+
+    @abstractmethod
+    def check_availability(self) -> StreamAvailability:
+        """
+        :return: If the stream is available and if not, why
+        """
