@@ -6,7 +6,8 @@ import json
 import re
 from typing import Any
 
-from jsonschema import RefResolver
+from referencing import Registry, Resource
+from referencing.jsonschema import DRAFT7
 
 
 def resolve_refs(schema: dict[str, Any]) -> dict[str, Any]:
@@ -14,13 +15,14 @@ def resolve_refs(schema: dict[str, Any]) -> dict[str, Any]:
     For spec schemas generated using Pydantic models, the resulting JSON schema can contain refs between object
     relationships.
     """
-    json_schema_ref_resolver = RefResolver.from_schema(schema)
+    resource = Resource.from_contents(schema, default_specification=DRAFT7)
+    registry = Registry().with_resource("", resource)
+    resolver = registry.resolver()
     str_schema = json.dumps(schema)
     for ref_block in re.findall(r'{"\$ref": "#\/definitions\/.+?(?="})"}', str_schema):
         ref = json.loads(ref_block)["$ref"]
-        str_schema = str_schema.replace(
-            ref_block, json.dumps(json_schema_ref_resolver.resolve(ref)[1])
-        )
+        resolved = resolver.lookup(ref).contents
+        str_schema = str_schema.replace(ref_block, json.dumps(resolved))
     pyschema: dict[str, Any] = json.loads(str_schema)
     del pyschema["definitions"]
     return pyschema
